@@ -14,14 +14,14 @@ Usage::
 """
 from typing import IO, Any, Dict, Type, Union
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 from botocore.response import StreamingBody
 
 from .type_defs import (
-    DeleteThingShadowResponseResponseTypeDef,
-    GetThingShadowResponseResponseTypeDef,
-    ListNamedShadowsForThingResponseResponseTypeDef,
-    UpdateThingShadowResponseResponseTypeDef,
+    DeleteThingShadowResponseTypeDef,
+    GetThingShadowResponseTypeDef,
+    ListNamedShadowsForThingResponseTypeDef,
+    UpdateThingShadowResponseTypeDef,
 )
 
 __all__ = ("IoTDataPlaneClient",)
@@ -49,30 +49,35 @@ class Exceptions:
     UnsupportedDocumentEncodingException: Type[BotocoreClientError]
 
 
-class IoTDataPlaneClient:
+class IoTDataPlaneClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/iot-data.html#IoTDataPlane.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/iot-data.html#IoTDataPlane.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        IoTDataPlaneClient exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/iot-data.html#IoTDataPlane.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/iot-data.html#IoTDataPlane.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#can_paginate)
         """
 
     def delete_thing_shadow(
         self, *, thingName: str, shadowName: str = None
-    ) -> DeleteThingShadowResponseResponseTypeDef:
+    ) -> DeleteThingShadowResponseTypeDef:
         """
         Deletes the shadow for the specified thing.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/iot-data.html#IoTDataPlane.Client.delete_thing_shadow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/iot-data.html#IoTDataPlane.Client.delete_thing_shadow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#delete_thing_shadow)
         """
 
@@ -86,27 +91,27 @@ class IoTDataPlaneClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/iot-data.html#IoTDataPlane.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/iot-data.html#IoTDataPlane.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#generate_presigned_url)
         """
 
     def get_thing_shadow(
         self, *, thingName: str, shadowName: str = None
-    ) -> GetThingShadowResponseResponseTypeDef:
+    ) -> GetThingShadowResponseTypeDef:
         """
         Gets the shadow for the specified thing.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/iot-data.html#IoTDataPlane.Client.get_thing_shadow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/iot-data.html#IoTDataPlane.Client.get_thing_shadow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#get_thing_shadow)
         """
 
     def list_named_shadows_for_thing(
         self, *, thingName: str, nextToken: str = None, pageSize: int = None
-    ) -> ListNamedShadowsForThingResponseResponseTypeDef:
+    ) -> ListNamedShadowsForThingResponseTypeDef:
         """
         Lists the shadows for the specified thing.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/iot-data.html#IoTDataPlane.Client.list_named_shadows_for_thing)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/iot-data.html#IoTDataPlane.Client.list_named_shadows_for_thing)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#list_named_shadows_for_thing)
         """
 
@@ -116,7 +121,7 @@ class IoTDataPlaneClient:
         """
         Publishes state information.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/iot-data.html#IoTDataPlane.Client.publish)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/iot-data.html#IoTDataPlane.Client.publish)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#publish)
         """
 
@@ -126,10 +131,10 @@ class IoTDataPlaneClient:
         thingName: str,
         payload: Union[bytes, IO[bytes], StreamingBody],
         shadowName: str = None
-    ) -> UpdateThingShadowResponseResponseTypeDef:
+    ) -> UpdateThingShadowResponseTypeDef:
         """
         Updates the shadow for the specified thing.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/iot-data.html#IoTDataPlane.Client.update_thing_shadow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/iot-data.html#IoTDataPlane.Client.update_thing_shadow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#update_thing_shadow)
         """
